const WebpackAliyunOss = require('webpack-aliyun-oss');
const pxtorem = require('postcss-pxtorem');
const Dotenv = require('dotenv-webpack');
const path = require('path')
const vantTheme = path.resolve(__dirname, './src/assets/style/vant-theme.less');

let BASE_URL = '/';
const {
  DEPLOY,
  OSS_REGION,
  OSS_DIST,
  OSS_URL,
  OSS_ACCESS_KEY_ID,
  OSS_ACCESS_KEY_SECRET,
  OSS_BUCKET
} = process.env;
const UNIQUE_KEY = Math.random();
switch (DEPLOY) {
  case 'online':
    BASE_URL = `${OSS_URL}${UNIQUE_KEY}/`;
    break;
  default:
    BASE_URL = '/';
}
module.exports = {
  // productionSourceMap: DEPLOY !== 'online',
  lintOnSave: false,
  runtimeCompiler: true,
  /**
   * parallel 用于控制项目打包时是否并行执行任务。当设置为 false 时，不再并行执行，
   * 可能解决 Thread Loader(Worker 0) 中由于 worker-loader 与 thread-loader 冲突导致的打包失败问题。
   * node 16以上的版本该参数一定要是false，否则打包会失败
   * @link https://cli.vuejs.org/zh/config/#parallel
   */
  parallel: false,
  publicPath: BASE_URL,
  configureWebpack: {
    module: {
      rules: [
        {
          test: /\.js$/,
          exclude: /node_modules/,
          include: path.resolve('src'),
          use: [
            {
              loader: 'thread-loader',
              options: {
                workers: 4
              }
            }
          ]
        }
      ]
    },
    plugins: [
      // ComponentsPlugin({
      //   resolvers: [VantResolver()]
      // }),
      new Dotenv(),
      DEPLOY === 'online' ?
      new WebpackAliyunOss({
        from: ['./dist/**/**', '!./dist/**/*.html'], // build目录下除html之外的所有文件
        dist: `${OSS_DIST}/${UNIQUE_KEY}`, // oss上传目录
        region: OSS_REGION,
        accessKeyId: OSS_ACCESS_KEY_ID,
        accessKeySecret: OSS_ACCESS_KEY_SECRET,
        bucket: OSS_BUCKET,
        timeout: 1200000,
        deleteOrigin: true,
        deleteEmptyDir: true,
        overwrite: true
      }) :
      () => {}
    ]
  },
  css: {
    loaderOptions: {
      postcss: {
        plugins: [pxtorem({
          rootValue({
            file
          }) {
            if (file && (file.includes('/vant/') || file.includes('\\vant\\') || file.includes('vxe-table') || file.includes('ui-common/') || file.includes('ui-common\\'))) {
              return 37.5
            } else {
              return 75
            }
          },
          unitPrecision: 4, // 保留小数位
          propList: ['*'],
          // selectorBlackList: [''], //过滤的类名
          replace: true, // 默认直接替换属性
          mediaQuery: false,
          minPixelValue: 6 // 所有小于设置的样式都不被转换
        })],
      },
      less: {
        lessOptions: {
          modifyVars: {
            hack: `true; @import "${vantTheme}";`,
          },
        },
      },
    },
  },
  devServer: {
    port: 8080,
    disableHostCheck: true,
    progress: false,
    proxy: {
      '/pamirs': {
        // 支持跨域
        changeOrigin: true,
        target: 'https://one.oinone.top'
      }
    }
  }
};
